==> xreview_0.95.1.zip: xreview/xreview_view.php <==
<?php
require('../../mainfile.php');
$xoopsOption['template_main'] = "xreview_view.html";
include (XOOPS_ROOT_PATH.'/header.php');
$myts =& MyTextSanitizer::getInstance();

// -----------------------
// parameter
// -----------------------
$reviewset_id = intval($_GET['id']);

// -----------------------
// ReviewSet ܾ
// -----------------------
$sql	= "select * from ".$xoopsDB->prefix( 'xreview_manage' );
$sql .= " where id = ". $reviewset_id;
$res = $xoopsDB->query($sql);
while($row = $xoopsDB->fetchArray($res)){
	$target_uri_ids = $row['target_uri_ids'];
	// assign
	$xoopsTpl->assign("target_uri_ids", $myts->htmlSpecialChars( $target_uri_ids ));
	$xoopsTpl->assign("xreview_name", $myts->htmlSpecialChars( $row['xreview_name'] ));
	$xoopsTpl->assign("xreview_note", $myts->htmlSpecialChars( $row['xreview_note'] ));
}

// -----------------------
// uri-idʬ
// -----------------------
$target_uri_ids_buff = split(",",$target_uri_ids);
$target_uri_ids_buff = array_unique($target_uri_ids_buff);

// -----------------------
// (%)η׻
// -----------------------
$xoopsTpl->assign("xreview_width", 100 / count($target_uri_ids_buff) );

// -----------------------
// ReviewSet name
// -----------------------
$uri_buff = array();
$item = array();
$i = 0;
foreach($target_uri_ids_buff as $target_uri_id)
{
	// uri-id 
	$sql	= "select * from ".$xoopsDB->prefix( 'xreview_uri' );
	$sql .= " where id = ".intval($target_uri_id);
	$res = $xoopsDB->query($sql);
	if($row = $xoopsDB->fetchArray($res))
	{
		$request_uri = $row['request_uri'];
		$uri_buff[$i++] = $request_uri;
		$name = $row['review_name'];
		if ( $name == "" )
		{
			// name б'("no title"򤤤) :塢 or Ǥ褦
			$name = "no title";
		}

		//assign
		if( $row['link_flag'] ) {
			$item['review_name_link_plus'] = "<a href='".XOOPS_URL.$myts->htmlSpecialChars( $request_uri )."'>".$myts->htmlSpecialChars($name)."</a>";
		} else {
			$item['review_name_link_plus'] = $myts->htmlSpecialChars($name);
		}
		$item['review_name'] = $myts->htmlSpecialChars($name);
	}
	$xoopsTpl->append("head", $item);
}

//----------------
// ɾUser
// User : myName, myImage, review_data
//----------------
// sql
$sql	= "select user_id from " . $xoopsDB->prefix( 'xreview_data' );
$sql .= " where ";
$condition_buff = array();
for ($i=0;$i<count($uri_buff);$i++)
{
	$condition_buff[$i] = " request_uri = ".$xoopsDB->quoteString($uri_buff[$i]);
}
$sql .= join(" OR ", $condition_buff);
$sql .= " group by user_id";
// query
$res = $xoopsDB->query($sql);
while($row = $xoopsDB->fetchArray($res))
{
	$user_id = $row['user_id'];
	$user_sql	= "select uname, user_avatar from ".$xoopsDB->prefix( 'users' );
	$user_sql .= " where uid = " . intval($user_id);
	$user_res = $xoopsDB->query($user_sql);
	if($user_row = $xoopsDB->fetchArray($user_res))
	{
		//assign
		$item['user_id'] = $myts->htmlSpecialChars($user_id);
		$item['myName'] = $myts->htmlSpecialChars( $user_row['uname'] );
		$item['myImage'] = $myts->htmlSpecialChars( $user_row['user_avatar'] );
	}

	//----------
	// ɾ
	// HTML
	//----------
	$countents_buff = array();
	for ($j=0;$j<count($uri_buff);$j++)
	{
		$sql	= "select * from " . $xoopsDB->prefix( 'xreview_data' );
		$sql .= " where user_id = ".intval($user_id)." and request_uri = ".$xoopsDB->quoteString($uri_buff[$j]);
		$res_a = $xoopsDB->query($sql);
		if($row_a = $xoopsDB->fetchArray($res_a))
		{
			//ɾ
			$comment[$j] = $row_a['comment'];
			$point_gif = intval($row_a['point'])."_view.gif";
		} else {
			//ɾʤ
			$comment[$j] = "";
			$point_gif = "brank.gif";
		}
		$countents_buff[$j] = "<td class='odd' align='left' background='".XOOPS_URL."/modules/xreview/images/$point_gif' style='background-repeat:no-repeat;background-position:50% 50%;'>".$myts->htmlSpecialChars($comment[$j])."</td>";
	}
	$item['contents'] = join("",$countents_buff);
	$xoopsTpl->append("review_data", $item);
}

include (XOOPS_ROOT_PATH.'/footer.php');
?>

==> xreview_0.96.zip: xreview/xreview_view.php <==
<?php
// =======================================
// xoops module xreview
// xreview_view.php
// =======================================
require('../../mainfile.php');
$xoopsOption['template_main'] = "xreview_view.html";
include (XOOPS_ROOT_PATH.'/header.php');

// -----------------------
// 
// -----------------------
$myts =& MyTextSanitizer::getInstance();

// -----------------------
// parameter
// -----------------------
$reviewset_id = intval($_GET['id']);

// -----------------------
// ReviewSet ܾ
// -----------------------
$sql	= "select * from ".$xoopsDB->prefix( 'xreview_manage' );
$sql .= " where id = ". intval($reviewset_id);
$res = $xoopsDB->query($sql);
if($row = $xoopsDB->fetchArray($res)){
	// assign
	$xoopsTpl->assign("xreview_name", $myts->htmlSpecialChars( $row['xreview_name'] ));
	$xoopsTpl->assign("xreview_note", $myts->htmlSpecialChars( $row['xreview_note'] ));

	// -----------------------
	// uri-idʬ
	// -----------------------
	$target_uri_ids = $row['target_uri_ids'];
	$target_uri_ids_buff = split(",",$target_uri_ids);
	$target_uri_ids_buff = array_unique($target_uri_ids_buff);
}

// -----------------------
// (%)η׻
// -----------------------
$xoopsTpl->assign("xreview_width", 100 / count($target_uri_ids_buff) );

//ɾоݤο
$xoopsTpl->assign("xreviewset_count", count($target_uri_ids_buff) );

// -----------------------
// ReviewSet name
// -----------------------
$uri_buff = array();
$item = array();
$i = 0;
foreach($target_uri_ids_buff as $target_uri_id)
{
	// uri-id 
	$sql	= "select * from ".$xoopsDB->prefix( 'xreview_uri' );
	$sql .= " where id = ".intval($target_uri_id);
	$res = $xoopsDB->query($sql);
	if($row = $xoopsDB->fetchArray($res))
	{
		$request_uri = $row['request_uri'];
		$uri_buff[$i++] = $request_uri;
		$name = $row['review_name'];
		if ( $name == "" )
		{
			// name б'("no title"򤤤) :塢 or Ǥ褦
			$name = "no title";
		}

		//assign
		$item['link_flag'] = $myts->htmlSpecialChars($row['link_flag']);
		$item['review_name_url'] = XOOPS_URL.$myts->htmlSpecialChars( $request_uri );
		$item['review_name_label'] = $myts->htmlSpecialChars($name);
		$item['review_name'] = $myts->htmlSpecialChars($name);
	}
	$xoopsTpl->append("head", $item);
}

//-------------------------------------
// ɾUser
// User : myName, myImage, review_data
//-------------------------------------
$sql	= "select user_id from " . $xoopsDB->prefix( 'xreview_data' );
$sql .= " where ";
$condition_buff = array();
for ($i=0;$i<count($uri_buff);$i++)
{
	$condition_buff[$i] = " request_uri = ".$xoopsDB->quoteString($uri_buff[$i]);
}
$sql .= join(" OR ", $condition_buff);
$sql .= " group by user_id";
// query
$res = $xoopsDB->query($sql);

//ɾԤο
$xoopsTpl->assign("reviewer_count", $xoopsDB->getRowsNum($res) );

while($row = $xoopsDB->fetchArray($res))
{
	$user_id = $row['user_id'];
	$user_sql	= "select uname, user_avatar from ".$xoopsDB->prefix( 'users' );
	$user_sql .= " where uid = " . intval($user_id);
	$user_res = $xoopsDB->query($user_sql);
	if($user_row = $xoopsDB->fetchArray($user_res))
	{
		//assign
		$item['user_id'] = $myts->htmlSpecialChars($user_id);
		$item['myName'] = $myts->htmlSpecialChars( $user_row['uname'] );
		$item['myImage'] = $myts->htmlSpecialChars( $user_row['user_avatar'] );
	}

	//----------
	// ɾ
	// HTML
	//----------
	$countents_buff = array();
	for ($j=0;$j<count($uri_buff);$j++)
	{
		$sql	= "select * from " . $xoopsDB->prefix( 'xreview_data' );
		$sql .= " where user_id = ".intval($user_id)." and request_uri = ".$xoopsDB->quoteString($uri_buff[$j]);
		$res_a = $xoopsDB->query($sql);
		if($row_a = $xoopsDB->fetchArray($res_a))
		{
			//ɾ
			$comment[$j] = $row_a['comment'];
			$point_gif = intval($row_a['point'])."_view.gif";
		} else {
			//ɾʤ
			$comment[$j] = "";
			$point_gif = "brank.gif";
		}
		$item['review_point_img'][$j] = XOOPS_URL."/modules/xreview/images/$point_gif";
		$item['review_content'][$j] = $comment[$j];
	}
	$item['review_content_count'] = count($uri_buff);
	$xoopsTpl->append("review_data", $item);
}

$xoopsTpl->assign("review_list_subject", _MB_LABEL_REVIEW_VIEW_SUBJECT );
$xoopsTpl->assign("label_return_list", _MB_LABEL_RETURN_LIST );
$xoopsTpl->assign("label_user", _MB_LABEL_USER );

include (XOOPS_ROOT_PATH.'/footer.php');
?>
